<TS version="2.1" language="ar">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation type="unfinished"> انقر بزر الماوس الأيمن لتعديل العنوان أو التسمية</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation type="unfinished"> إنشاء عنوان جديد</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation type="unfinished"> &amp;جديد</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation type="unfinished"> احذف العنوان المحدد حاليًا من القائمة</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation type="unfinished"> أدخل العنوان أو التسمية للبحث</translation>
    </message>
    </context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Back</source>
        <translation type="unfinished">رجوع</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Error: %1</source>
        <translation type="unfinished">خطأ: %1</translation>
    </message>
    <message>
        <source>%1 didn't yet exit safely…</source>
        <translation type="unfinished">‫%1 لم يغلق بامان بعد…‬</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">‫القيمة‬</translation>
    </message>
    <message>
        <source>Enter a Bitcoin address (e.g. %1)</source>
        <translation type="unfinished">ادخل عنوان محفطة البتكوين (مثال %1)</translation>
    </message>
    <message>
        <source>Unroutable</source>
        <translation type="unfinished">‫غير قابل للتوجيه‬</translation>
    </message>
    <message>
        <source>Inbound</source>
        <extracomment>An inbound connection from a peer. An inbound connection is a connection initiated by a peer.</extracomment>
        <translation type="unfinished">‫وارد‬</translation>
    </message>
    <message>
        <source>Outbound</source>
        <extracomment>An outbound connection to a peer. An outbound connection is a connection initiated by us.</extracomment>
        <translation type="unfinished">‫صادر‬</translation>
    </message>
    <message>
        <source>Full Relay</source>
        <extracomment>Peer connection type that relays all network information.</extracomment>
        <translation type="unfinished">‫موصل كامل‬</translation>
    </message>
    <message>
        <source>Block Relay</source>
        <extracomment>Peer connection type that relays network information about blocks and not transactions or addresses.</extracomment>
        <translation type="unfinished">‫موصل طابق‬</translation>
    </message>
    <message>
        <source>Manual</source>
        <extracomment>Peer connection type established manually through one of several methods.</extracomment>
        <translation type="unfinished">يدوي</translation>
    </message>
    <message>
        <source>Feeler</source>
        <extracomment>Short-lived peer connection type that tests the aliveness of known addresses.</extracomment>
        <translation type="unfinished">‫تفقدي‬</translation>
    </message>
    <message>
        <source>Address Fetch</source>
        <extracomment>Short-lived peer connection type that solicits known addresses from a peer.</extracomment>
        <translation type="unfinished">‫جلب العنوان‬</translation>
    </message>
    <message>
        <source>%1 d</source>
        <translation type="unfinished">%1 يوم</translation>
    </message>
    <message>
        <source>%1 h</source>
        <translation type="unfinished">%1 ساعة</translation>
    </message>
    <message>
        <source>%1 m</source>
        <translation type="unfinished">%1 دقيقة</translation>
    </message>
    <message>
        <source>%1 s</source>
        <translation type="unfinished">%1 ثانية</translation>
    </message>
    <message>
        <source>None</source>
        <translation type="unfinished">لا شيء</translation>
    </message>
    <message>
        <source>%1 ms</source>
        <translation type="unfinished">%1 جزء من الثانية</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform>%n second(s)</numerusform>
            <numerusform>%n second(s)</numerusform>
            <numerusform>%n second(s)</numerusform>
            <numerusform>%n second(s)</numerusform>
            <numerusform>%n second(s)</numerusform>
            <numerusform>%n‫‫ ثواني‬</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform>%n minute(s)</numerusform>
            <numerusform>%n minute(s)</numerusform>
            <numerusform>%n minute(s)</numerusform>
            <numerusform>%n minute(s)</numerusform>
            <numerusform>%n minute(s)</numerusform>
            <numerusform>%n ‫دقائق‬</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform>%n hour(s)</numerusform>
            <numerusform>%n hour(s)</numerusform>
            <numerusform>%n hour(s)</numerusform>
            <numerusform>%n hour(s)</numerusform>
            <numerusform>%n hour(s)</numerusform>
            <numerusform>%n‫ساعات‬</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform>%n day(s)</numerusform>
            <numerusform>%n day(s)</numerusform>
            <numerusform>%n day(s)</numerusform>
            <numerusform>%n day(s)</numerusform>
            <numerusform>%n day(s)</numerusform>
            <numerusform>%n ‫أيام‬</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform>%n week(s)</numerusform>
            <numerusform>%n week(s)</numerusform>
            <numerusform>%n week(s)</numerusform>
            <numerusform>%n week(s)</numerusform>
            <numerusform>%n week(s)</numerusform>
            <numerusform>%n ‫أسابيع‬</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 and %2</source>
        <translation type="unfinished">%1 و %2</translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform>%n year(s)</numerusform>
            <numerusform>%n year(s)</numerusform>
            <numerusform>%n year(s)</numerusform>
            <numerusform>%n year(s)</numerusform>
            <numerusform>%n year(s)</numerusform>
            <numerusform>%n ‫سنوات‬</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 B</source>
        <translation type="unfinished">%1 بايت</translation>
    </message>
    <message>
        <source>%1 kB</source>
        <translation type="unfinished">%1 كيلو بايت</translation>
    </message>
    <message>
        <source>%1 MB</source>
        <translation type="unfinished">%1 ‫ميجابايت‬</translation>
    </message>
    <message>
        <source>%1 GB</source>
        <translation type="unfinished">%1 ‫جيجابايت‬</translation>
    </message>
    <message>
        <source>default wallet</source>
        <translation type="unfinished">‫محفظة افتراضية‬</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>&amp;Overview</source>
        <translation type="unfinished">&amp;نظرة عامة</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation type="unfinished">إظهار نظرة عامة على المحفظة</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation type="unfinished">&amp;المعاملات</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation type="unfinished">تصفح تاريخ العمليات</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation type="unfinished">خروج</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation type="unfinished">إغلاق التطبيق</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation type="unfinished">حوالي %1</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation type="unfinished">أظهر المعلومات حولة %1</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation type="unfinished">عن &amp;Qt</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation type="unfinished">اظهر المعلومات</translation>
    </message>
    <message>
        <source>Modify configuration options for %1</source>
        <translation type="unfinished">تغيير خيارات الإعداد لأساس ل%1</translation>
    </message>
    <message>
        <source>Create a new wallet</source>
        <translation type="unfinished">إنشاء محفظة جديدة</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation type="unfinished">المحفظة:</translation>
    </message>
    <message>
        <source>Network activity disabled.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">تم إلغاء تفعيل الشبكه</translation>
    </message>
    <message>
        <source>Proxy is &lt;b&gt;enabled&lt;/b&gt;: %1</source>
        <translation type="unfinished">%1 اتصال نشط بشبكة البيتكوين</translation>
    </message>
    <message>
        <source>Send coins to a Bitcoin address</source>
        <translation type="unfinished">ارسل عملات الى عنوان بيتكوين</translation>
    </message>
    <message>
        <source>Backup wallet to another location</source>
        <translation type="unfinished">احفظ نسخة احتياطية للمحفظة في مكان آخر</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation type="unfinished">تغيير كلمة المرور المستخدمة لتشفير المحفظة</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation type="unfinished">&amp;ارسل</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation type="unfinished">&amp;استقبل</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet…</source>
        <translation type="unfinished">&amp; تشفير المحفظة</translation>
    </message>
    <message>
        <source>Encrypt the private keys that belong to your wallet</source>
        <translation type="unfinished">تشفير المفتاح الخاص بمحفظتك</translation>
    </message>
    <message>
        <source>&amp;Backup Wallet…</source>
        <translation type="unfinished">&amp; محفظة احتياطية</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase…</source>
        <translation type="unfinished">وتغيير العبارات...</translation>
    </message>
    <message>
        <source>Sign &amp;message…</source>
        <translation type="unfinished">علامة ورسالة...</translation>
    </message>
    <message>
        <source>Sign messages with your Bitcoin addresses to prove you own them</source>
        <translation type="unfinished">وقَع الرسائل بواسطة ال: Bitcoin الخاص بك لإثبات امتلاكك لهم</translation>
    </message>
    <message>
        <source>&amp;Verify message…</source>
        <translation type="unfinished">&amp; تحقق من الرسالة</translation>
    </message>
    <message>
        <source>Verify messages to ensure they were signed with specified Bitcoin addresses</source>
        <translation type="unfinished">تحقق من الرسائل للتأكد من أنَها وُقعت برسائل Bitcoin محدَدة</translation>
    </message>
    <message>
        <source>&amp;Load PSBT from file…</source>
        <translation type="unfinished">وتحميل PSBT من ملف...</translation>
    </message>
    <message>
        <source>Open &amp;URI…</source>
        <translation type="unfinished">فتح ورابط...</translation>
    </message>
    <message>
        <source>Close Wallet…</source>
        <translation type="unfinished">اغلاق المحفظة</translation>
    </message>
    <message>
        <source>Create Wallet…</source>
        <translation type="unfinished">انشاء المحفظة</translation>
    </message>
    <message>
        <source>Close All Wallets…</source>
        <translation type="unfinished">اغلاق جميع المحافظ</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="unfinished">&amp;ملف</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation type="unfinished">&amp;الاعدادات</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="unfinished">&amp;مساعدة</translation>
    </message>
    <message>
        <source>Tabs toolbar</source>
        <translation type="unfinished">شريط أدوات علامات التبويب</translation>
    </message>
    <message>
        <source>Synchronizing with network…</source>
        <translation type="unfinished">مزامنة مع الشبكة ...</translation>
    </message>
    <message>
        <source>Indexing blocks on disk…</source>
        <translation type="unfinished">كتل الفهرسة على القرص ...</translation>
    </message>
    <message>
        <source>Processing blocks on disk…</source>
        <translation type="unfinished">كتل المعالجة على القرص ...</translation>
    </message>
    <message>
        <source>Connecting to peers…</source>
        <translation type="unfinished">‫الاتصال بالأقران…‬</translation>
    </message>
    <message>
        <source>Request payments (generates QR codes and bitcoin: URIs)</source>
        <translation type="unfinished">‫أطلب مدفوعات (أنشئ رموز استجابة (QR Codes) وعناوين بتكوين)‬</translation>
    </message>
    <message>
        <source>Show the list of used sending addresses and labels</source>
        <translation type="unfinished">‫عرض قائمة العناوين المرسِلة والمذكرات (المستخدمة سابقا)‬</translation>
    </message>
    <message>
        <source>Show the list of used receiving addresses and labels</source>
        <translation type="unfinished">‫عرض قائمة العناوين المستلمة والمذكرات (المستخدمة سابقا)‬</translation>
    </message>
    <message>
        <source>&amp;Command-line options</source>
        <translation type="unfinished">&amp;خيارات سطر الأوامر</translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform>Processed %n block(s) of transaction history.</numerusform>
            <numerusform>Processed %n block(s) of transaction history.</numerusform>
            <numerusform>Processed %n block(s) of transaction history.</numerusform>
            <numerusform>Processed %n block(s) of transaction history.</numerusform>
            <numerusform>Processed %n block(s) of transaction history.</numerusform>
            <numerusform>Processed %n block(s) of transaction history.</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 behind</source>
        <translation type="unfinished">‫متأخر‬ %1</translation>
    </message>
    <message>
        <source>Catching up…</source>
        <translation type="unfinished">‫يجري التدارك…‬</translation>
    </message>
    <message>
        <source>Last received block was generated %1 ago.</source>
        <translation type="unfinished">‫آخر طابق مستلم تم بناءه قبل %1.</translation>
    </message>
    <message>
        <source>Transactions after this will not yet be visible.</source>
        <translation type="unfinished">‫المعاملات بعد هذه لن تكون ظاهرة فورا.‬</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">خطأ</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation type="unfinished">تحذير</translation>
    </message>
    <message>
        <source>Information</source>
        <translation type="unfinished">المعلومات</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation type="unfinished">‫حديث‬</translation>
    </message>
    <message>
        <source>Load Partially Signed Bitcoin Transaction</source>
        <translation type="unfinished">‫تحميل معاملة بتكوين موقعة جزئيًا (PSBT)‬</translation>
    </message>
    <message>
        <source>Load PSBT from &amp;clipboard…</source>
        <translation type="unfinished">‫تحميل معاملة بتكوين موقعة جزئيا (‫PSBT) من &amp;الحافظة…‬</translation>
    </message>
    <message>
        <source>Load Partially Signed Bitcoin Transaction from clipboard</source>
        <translation type="unfinished">‫تحميل معاملة بتكوين موقعة جزئيًا ‫(‫PSBT) من الحافظة‬</translation>
    </message>
    <message>
        <source>Node window</source>
        <translation type="unfinished">‫نافذة النود‬</translation>
    </message>
    <message>
        <source>Open node debugging and diagnostic console</source>
        <translation type="unfinished">‫افتح وحدة التحكم في تصحيح الأخطاء والتشخيص للنود‬</translation>
    </message>
    <message>
        <source>&amp;Sending addresses</source>
        <translation type="unfinished">‫&amp;عناوين الإرسال‬</translation>
    </message>
    <message>
        <source>&amp;Receiving addresses</source>
        <translation type="unfinished">‫&amp;عناوين الإستلام‬</translation>
    </message>
    <message>
        <source>Open a bitcoin: URI</source>
        <translation type="unfinished">‫افتح رابط بتكوين: URI‬</translation>
    </message>
    <message>
        <source>Open Wallet</source>
        <translation type="unfinished">افتح المحفظة</translation>
    </message>
    <message>
        <source>Open a wallet</source>
        <translation type="unfinished">‫افتح محفظة‬</translation>
    </message>
    <message>
        <source>Close wallet</source>
        <translation type="unfinished">اغلق المحفظة</translation>
    </message>
    <message>
        <source>Restore Wallet…</source>
        <extracomment>Name of the menu item that restores wallet from a backup file.</extracomment>
        <translation type="unfinished">‫استعادة محفظة…‬</translation>
    </message>
    <message>
        <source>Restore a wallet from a backup file</source>
        <extracomment>Status tip for Restore Wallet menu item</extracomment>
        <translation type="unfinished">‫استعادة محفظة من ملف النسخ الاحتياطي‬</translation>
    </message>
    <message>
        <source>Close all wallets</source>
        <translation type="unfinished">‫إغلاق جميع المحافظ‬</translation>
    </message>
    <message>
        <source>Show the %1 help message to get a list with possible Bitcoin command-line options</source>
        <translation type="unfinished">‫اعرض %1 رسالة المساعدة للحصول على قائمة من خيارات سطر أوامر البتكوين المحتملة‬</translation>
    </message>
    <message>
        <source>&amp;Mask values</source>
        <translation type="unfinished">&amp;إخفاء القيم</translation>
    </message>
    <message>
        <source>Mask the values in the Overview tab</source>
        <translation type="unfinished">‫إخفاء القيم في علامة التبويب: نظرة عامة‬</translation>
    </message>
    <message>
        <source>No wallets available</source>
        <translation type="unfinished">‫لا يوجد محفظة متاحة‬</translation>
    </message>
    <message>
        <source>Wallet Data</source>
        <extracomment>Name of the wallet data file format.</extracomment>
        <translation type="unfinished">بيانات المحفظة</translation>
    </message>
    <message>
        <source>Load Wallet Backup</source>
        <extracomment>The title for Restore Wallet File Windows</extracomment>
        <translation type="unfinished">‫تحميل النسخة الاحتياطية لمحفظة‬</translation>
    </message>
    <message>
        <source>Wallet Name</source>
        <extracomment>Label of the input field where the name of the wallet is entered.</extracomment>
        <translation type="unfinished">إسم المحفظة</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation type="unfinished">&amp;نافذة</translation>
    </message>
    <message>
        <source>Zoom</source>
        <translation type="unfinished">تكبير</translation>
    </message>
    <message>
        <source>Main Window</source>
        <translation type="unfinished">النافذة الرئيسية</translation>
    </message>
    <message>
        <source>%1 client</source>
        <translation type="unfinished">‫العميل %1</translation>
    </message>
    <message>
        <source>&amp;Hide</source>
        <translation type="unfinished">‫&amp;اخفاء‬</translation>
    </message>
    <message>
        <source>S&amp;how</source>
        <translation type="unfinished">‫ع&amp;رض‬</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to Bitcoin network.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">
            <numerusform>%n active connection(s) to Bitcoin network.</numerusform>
            <numerusform>%n active connection(s) to Bitcoin network.</numerusform>
            <numerusform>%n active connection(s) to Bitcoin network.</numerusform>
            <numerusform>%n active connection(s) to Bitcoin network.</numerusform>
            <numerusform>%n active connection(s) to Bitcoin network.</numerusform>
            <numerusform>%n اتصال نشط بشبكة البتكوين.</numerusform>
        </translation>
    </message>
    <message>
        <source>Click for more actions.</source>
        <extracomment>A substring of the tooltip. "More actions" are available via the context menu.</extracomment>
        <translation type="unfinished">انقر لمزيد من الإجراءات.</translation>
    </message>
    <message>
        <source>Show Peers tab</source>
        <extracomment>A context menu item. The "Peers tab" is an element of the "Node window".</extracomment>
        <translation type="unfinished">‫إظهار تبويب الأقران‬</translation>
    </message>
    <message>
        <source>Disable network activity</source>
        <extracomment>A context menu item.</extracomment>
        <translation type="unfinished">تعطيل نشاط الشبكة</translation>
    </message>
    <message>
        <source>Enable network activity</source>
        <extracomment>A context menu item. The network activity was disabled previously.</extracomment>
        <translation type="unfinished">تمكين نشاط الشبكة</translation>
    </message>
    <message>
        <source>Pre-syncing Headers (%1%)…</source>
        <translation type="unfinished">ما قبل مزامنة الرؤوس (%1%)…</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation type="unfinished">خطأ: %1</translation>
    </message>
    <message>
        <source>Private key &lt;b&gt;disabled&lt;/b&gt;</source>
        <translation type="unfinished">المفتاح الخاص &lt;b&gt;معطل&lt;/b&gt;</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>After Fee:</source>
        <translation type="unfinished">بعد الرسوم:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation type="unfinished">تعديل:</translation>
    </message>
    <message>
        <source>(un)select all</source>
        <translation type="unfinished">‫الغاء تحديد الكل‬</translation>
    </message>
    <message>
        <source>Tree mode</source>
        <translation type="unfinished">صيغة الشجرة</translation>
    </message>
    <message>
        <source>List mode</source>
        <translation type="unfinished">صيغة القائمة</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">‫القيمة‬</translation>
    </message>
    <message>
        <source>Received with label</source>
        <translation type="unfinished">‫استُلم وله مذكرة‬</translation>
    </message>
    <message>
        <source>Received with address</source>
        <translation type="unfinished">‫مستلم مع عنوان‬</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished">التاريخ</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation type="unfinished">التأكيدات</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation type="unfinished">‫نافذ‬</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation type="unfinished">‫نسخ القيمة‬</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">‫&amp;انسخ العنوان‬</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation type="unfinished">‫نسخ &amp;مذكرة‬</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">‫نسخ &amp;القيمة‬</translation>
    </message>
    <message>
        <source>Copy transaction &amp;ID and output index</source>
        <translation type="unfinished">‫نسخ &amp;معرف العملية وفهرس المخرجات‬</translation>
    </message>
    <message>
        <source>L&amp;ock unspent</source>
        <translation type="unfinished">قفل غير منفق</translation>
    </message>
    <message>
        <source>&amp;Unlock unspent</source>
        <translation type="unfinished">&amp; إفتح غير المنفق</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation type="unfinished">نسخ الكمية </translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation type="unfinished">نسخ الرسوم</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation type="unfinished">نسخ بعد الرسوم</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation type="unfinished">نسخ البايتات </translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation type="unfinished">‫نسخ الفكة‬</translation>
    </message>
    <message>
        <source>(%1 locked)</source>
        <translation type="unfinished">(%1 تم قفله)</translation>
    </message>
    <message>
        <source>Can vary +/- %1 satoshi(s) per input.</source>
        <translation type="unfinished">يمكن أن يختلف +/- %1 من ساتوشي(s) لكل إدخال.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(بدون وسم)</translation>
    </message>
    <message>
        <source>change from %1 (%2)</source>
        <translation type="unfinished">تغير من %1 (%2)</translation>
    </message>
    <message>
        <source>(change)</source>
        <translation type="unfinished">(تغير)</translation>
    </message>
</context>
<context>
    <name>CreateWalletActivity</name>
    <message>
        <source>Create Wallet</source>
        <extracomment>Title of window indicating the progress of creation of a new wallet.</extracomment>
        <translation type="unfinished">إنشاء محفظة</translation>
    </message>
    <message>
        <source>Creating Wallet &lt;b&gt;%1&lt;/b&gt;…</source>
        <extracomment>Descriptive text of the create wallet progress window which indicates to the user which wallet is currently being created.</extracomment>
        <translation type="unfinished">جاري انشاء المحفظة &lt;b&gt;%1&lt;/b&gt;... </translation>
    </message>
    <message>
        <source>Create wallet failed</source>
        <translation type="unfinished">فشل إنشاء المحفظة</translation>
    </message>
    <message>
        <source>Create wallet warning</source>
        <translation type="unfinished">تحذير إنشاء محفظة</translation>
    </message>
    <message>
        <source>Can't list signers</source>
        <translation type="unfinished">لا يمكن سرد الموقعين</translation>
    </message>
    </context>
<context>
    <name>WalletController</name>
    <message>
        <source>Are you sure you wish to close the wallet &lt;i&gt;%1&lt;/i&gt;?</source>
        <translation type="unfinished">هل أنت متأكد من رغبتك في إغلاق المحفظة &lt;i&gt;%1&lt;/i&gt;؟ </translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of space available</source>
        <translation type="unfinished">
            <numerusform>%n GB of space available</numerusform>
            <numerusform>%n GB of space available</numerusform>
            <numerusform>%n GB of space available</numerusform>
            <numerusform>%n GB of space available</numerusform>
            <numerusform>%n GB of space available</numerusform>
            <numerusform>%n GB of space available</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform>(of %n GB needed)</numerusform>
            <numerusform>(of %n GB needed)</numerusform>
            <numerusform>(of %n GB needed)</numerusform>
            <numerusform>(of %n GB needed)</numerusform>
            <numerusform>(of %n GB needed)</numerusform>
            <numerusform>(of %n GB needed)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform>(%n GB needed for full chain)</numerusform>
            <numerusform>(%n GB needed for full chain)</numerusform>
            <numerusform>(%n GB needed for full chain)</numerusform>
            <numerusform>(%n GB needed for full chain)</numerusform>
            <numerusform>(%n GB needed for full chain)</numerusform>
            <numerusform>(%n GB needed for full chain)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>(sufficient to restore backups %n day(s) old)</source>
        <extracomment>Explanatory text on the capability of the current prune target.</extracomment>
        <translation type="unfinished">
            <numerusform>(sufficient to restore backups %n day(s) old)</numerusform>
            <numerusform>(sufficient to restore backups %n day(s) old)</numerusform>
            <numerusform>(sufficient to restore backups %n day(s) old)</numerusform>
            <numerusform>(sufficient to restore backups %n day(s) old)</numerusform>
            <numerusform>(sufficient to restore backups %n day(s) old)</numerusform>
            <numerusform>(sufficient to restore backups %n day(s) old)</numerusform>
        </translation>
    </message>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Automatically open the Bitcoin client port on the router. This only works when your router supports PCP or NAT-PMP and it is enabled. The external port could be random.</source>
        <translation type="unfinished">افتح تلقائيًا منفذ عميل البتكوين على جهاز التوجيه. يعمل هذا فقط عندما يدعم جهاز التوجيه الخاص بك PCP أو NAT-PMP ويتم تمكينه. يمكن أن يكون المنفذ الخارجي عشوائيًا</translation>
    </message>
    <message>
        <source>Options set in this dialog are overridden by the command line:</source>
        <translation type="unfinished">‫التفضيلات المعينة عن طريق سطر الأوامر لها أولوية أكبر وتتجاوز التفضيلات المختارة هنا:‬</translation>
    </message>
    <message>
        <source>Open the %1 configuration file from the working directory.</source>
        <translation type="unfinished">‫فتح ملف %1 الإعداد من مجلد العمل.‬</translation>
    </message>
    <message>
        <source>Open Configuration File</source>
        <translation type="unfinished">‫فتح ملف الإعداد‬</translation>
    </message>
    <message>
        <source>Reset all client options to default.</source>
        <translation type="unfinished">إعادة تعيين كل إعدادات العميل للحالة الإفتراضية.</translation>
    </message>
    <message>
        <source>&amp;Reset Options</source>
        <translation type="unfinished">‫&amp;اعادة تهيئة الخيارات‬</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation type="unfinished">&amp;الشبكة</translation>
    </message>
    <message>
        <source>Prune &amp;block storage to</source>
        <translation type="unfinished">‫اختصار &amp;تخزين الطابق</translation>
    </message>
    <message>
        <source>GB</source>
        <translation type="unfinished">‫جيجابايت‬</translation>
    </message>
    <message>
        <source>Reverting this setting requires re-downloading the entire blockchain.</source>
        <translation type="unfinished">‫العودة الى هذا الاعداد تتطلب إعادة تنزيل الطوابق المتتالية بالكامل.‬</translation>
    </message>
    <message>
        <source>Accept connections from outside.</source>
        <translation type="unfinished">قبول الاتصالات من الخارج.</translation>
    </message>
    <message>
        <source>Allow incomin&amp;g connections</source>
        <translation type="unfinished">‫السماح بالاتصالات الوارد&amp;ة‬</translation>
    </message>
    <message>
        <source>Connect to the Bitcoin network through a SOCKS5 proxy.</source>
        <translation type="unfinished">الاتصال بشبكة البتكوين عبر وكيل SOCKS5.</translation>
    </message>
    <message>
        <source>&amp;Connect through SOCKS5 proxy (default proxy):</source>
        <translation type="unfinished">الاتصال من خلال وكيل SOCKS5 (الوكيل الافتراضي):</translation>
    </message>
    <message>
        <source>Proxy &amp;IP:</source>
        <translation type="unfinished">بروكسي &amp;اي بي:</translation>
    </message>
    <message>
        <source>&amp;Port:</source>
        <translation type="unfinished">&amp;المنفذ:</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation type="unfinished">منفذ البروكسي (مثلا 9050)</translation>
    </message>
    <message>
        <source>Used for reaching peers via:</source>
        <translation type="unfinished">مستخدم للاتصال بالاقران من خلال:</translation>
    </message>
    <message>
        <source>Tor</source>
        <translation type="unfinished">تور</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation type="unfinished">‫&amp;نافذة‬</translation>
    </message>
    <message>
        <source>Show the icon in the system tray.</source>
        <translation type="unfinished">عرض الأيقونة في زاوية الأيقونات.</translation>
    </message>
    <message>
        <source>&amp;Show tray icon</source>
        <translation type="unfinished">‫&amp;اعرض الأيقونة في الزاوية‬</translation>
    </message>
    <message>
        <source>Show only a tray icon after minimizing the window.</source>
        <translation type="unfinished">‫عرض الأيقونة في زاوية الأيقونات فقط بعد تصغير النافذة.‬</translation>
    </message>
    <message>
        <source>&amp;Minimize to the tray instead of the taskbar</source>
        <translation type="unfinished">‫التصغير إلى زاوية الأيقونات بدلاً من شريط المهام‬</translation>
    </message>
    <message>
        <source>M&amp;inimize on close</source>
        <translation type="unfinished">‫ت&amp;صغير عند الإغلاق‬</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation type="unfinished">&amp;عرض</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation type="unfinished">واجهة المستخدم &amp;اللغة:</translation>
    </message>
    <message>
        <source>The user interface language can be set here. This setting will take effect after restarting %1.</source>
        <translation type="unfinished">‫يمكن ضبط الواجهة اللغوية للمستخدم من هنا. هذا الإعداد يتطلب إعادة تشغيل %1.‬</translation>
    </message>
    <message>
        <source>&amp;Unit to show amounts in:</source>
        <translation type="unfinished">‫وحدة لعرض القيم:‬</translation>
    </message>
    <message>
        <source>Choose the default subdivision unit to show in the interface and when sending coins.</source>
        <translation type="unfinished">‫اختر وحدة التقسيم الفرعية الافتراضية للعرض في الواجهة وعند إرسال البتكوين.‬</translation>
    </message>
    <message>
        <source>Third-party URLs (e.g. a block explorer) that appear in the transactions tab as context menu items. %s in the URL is replaced by transaction hash. Multiple URLs are separated by vertical bar |.</source>
        <translation type="unfinished">‫عناوين أطراف أخرى (مثل: مستكشف الطوابق) تظهر في النافذة المبوبة للعمليات كخيار في القائمة المنبثقة. %s في الرابط تُستبدل بمعرف التجزئة. سيتم فصل العناوين بخط أفقي |.‬</translation>
    </message>
    <message>
        <source>&amp;Third-party transaction URLs</source>
        <translation type="unfinished">‫&amp;عناوين عمليات أطراف أخرى‬</translation>
    </message>
    <message>
        <source>Whether to show coin control features or not.</source>
        <translation type="unfinished">‫ما اذا أردت إظهار ميزات التحكم في وحدات البتكوين أم لا.‬</translation>
    </message>
    <message>
        <source>Connect to the Bitcoin network through a separate SOCKS5 proxy for Tor onion services.</source>
        <translation type="unfinished">اتصل بشبكة بتكوين من خلال وكيل SOCKS5 منفصل لخدمات Tor onion.</translation>
    </message>
    <message>
        <source>Use separate SOCKS&amp;5 proxy to reach peers via Tor onion services:</source>
        <translation type="unfinished">استخدم بروكسي SOCKS5 منفصل للوصول إلى الأقران عبر خدمات Tor onion:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished">&amp;تم</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished">الغاء</translation>
    </message>
    <message>
        <source>Compiled without external signing support (required for external signing)</source>
        <extracomment>"External signing" means using devices such as hardware wallets.</extracomment>
        <translation type="unfinished">مجمعة بدون دعم توقيع خارجي (مطلوب للتوقيع الخارجي)</translation>
    </message>
    <message>
        <source>default</source>
        <translation type="unfinished">الافتراضي</translation>
    </message>
    <message>
        <source>none</source>
        <translation type="unfinished">لا شيء</translation>
    </message>
    <message>
        <source>Confirm options reset</source>
        <extracomment>Window title text of pop-up window shown when the user has chosen to reset options.</extracomment>
        <translation type="unfinished">تأكيد استعادة الخيارات</translation>
    </message>
    <message>
        <source>Client restart required to activate changes.</source>
        <extracomment>Text explaining that the settings changed will not come into effect until the client is restarted.</extracomment>
        <translation type="unfinished">‫يجب إعادة تشغيل العميل لتفعيل التغييرات.‬</translation>
    </message>
    <message>
        <source>Current settings will be backed up at "%1".</source>
        <extracomment>Text explaining to the user that the client's current settings will be backed up at a specific location. %1 is a stand-in argument for the backup location's path.</extracomment>
        <translation type="unfinished">‫سيتم النسخ الاحتياطي للاعدادات على “%1”.‬".</translation>
    </message>
    <message>
        <source>Client will be shut down. Do you want to proceed?</source>
        <extracomment>Text asking the user to confirm if they would like to proceed with a client shutdown.</extracomment>
        <translation type="unfinished">‫سوف يتم إيقاف العميل تماماً. هل تريد الإستمرار؟‬</translation>
    </message>
    <message>
        <source>Configuration options</source>
        <extracomment>Window title text of pop-up box that allows opening up of configuration file.</extracomment>
        <translation type="unfinished">‫خيارات الإعداد‬</translation>
    </message>
    <message>
        <source>The configuration file is used to specify advanced user options which override GUI settings. Additionally, any command-line options will override this configuration file.</source>
        <extracomment>Explanatory text about the priority order of instructions considered by client. The order from high to low being: command-line, configuration file, GUI settings.</extracomment>
        <translation type="unfinished">‫يتم استخدام ملف الإعداد لتحديد خيارات المستخدم المتقدمة التي تتجاوز إعدادات واجهة المستخدم الرسومية. بالإضافة إلى ذلك ، ستتجاوز خيارات سطر الأوامر ملف الإعداد هذا.‬</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">إلغاء</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">خطأ</translation>
    </message>
    <message>
        <source>The configuration file could not be opened.</source>
        <translation type="unfinished">‫لم تتمكن من فتح ملف الإعداد.‬</translation>
    </message>
    <message>
        <source>This change would require a client restart.</source>
        <translation type="unfinished">هذا التغيير يتطلب إعادة تشغيل العميل بشكل كامل.</translation>
    </message>
    <message>
        <source>The supplied proxy address is invalid.</source>
        <translation type="unfinished">‫عنوان الوكيل الذي تم ادخاله غير صالح.‬</translation>
    </message>
</context>
<context>
    <name>OptionsModel</name>
    <message>
        <source>Could not read setting "%1", %2.</source>
        <translation type="unfinished">‫لا يمكن قراءة الاعدادات “%1”, %2.‬</translation>
    </message>
</context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation type="unfinished">نمودج</translation>
    </message>
    <message>
        <source>The displayed information may be out of date. Your wallet automatically synchronizes with the Bitcoin network after a connection is established, but this process has not completed yet.</source>
        <translation type="unfinished">قد تكون المعلومات المعروضة قديمة. تتزامن محفظتك تلقائيًا مع شبكة البتكوين بعد إنشاء الاتصال، ولكن هذه العملية لم تكتمل بعد.</translation>
    </message>
    <message>
        <source>Watch-only:</source>
        <translation type="unfinished">‫مراقبة فقط:‬</translation>
    </message>
    <message>
        <source>Available:</source>
        <translation type="unfinished">‫متاح:‬</translation>
    </message>
    <message>
        <source>Your current spendable balance</source>
        <translation type="unfinished">‫الرصيد المتاح للصرف‬</translation>
    </message>
    <message>
        <source>Pending:</source>
        <translation type="unfinished">معلق:</translation>
    </message>
    <message>
        <source>Total of transactions that have yet to be confirmed, and do not yet count toward the spendable balance</source>
        <translation type="unfinished">إجمالي المعاملات التي لم يتم تأكيدها بعد ولا تحتسب ضمن الرصيد القابل للانفاق</translation>
    </message>
    <message>
        <source>Immature:</source>
        <translation type="unfinished">‫غير ناضج:‬</translation>
    </message>
    <message>
        <source>Mined balance that has not yet matured</source>
        <translation type="unfinished">الرصيد المعدّن الذي لم ينضج بعد</translation>
    </message>
    <message>
        <source>Balances</source>
        <translation type="unfinished">الأرصدة</translation>
    </message>
    <message>
        <source>Total:</source>
        <translation type="unfinished">المجموع:</translation>
    </message>
    <message>
        <source>Your current total balance</source>
        <translation type="unfinished">رصيدك الكلي الحالي</translation>
    </message>
    <message>
        <source>Your current balance in watch-only addresses</source>
        <translation type="unfinished">‫رصيد عناوين المراقبة‬</translation>
    </message>
    <message>
        <source>Spendable:</source>
        <translation type="unfinished">قابل للصرف:</translation>
    </message>
    <message>
        <source>Recent transactions</source>
        <translation type="unfinished">العمليات الأخيرة</translation>
    </message>
    <message>
        <source>Unconfirmed transactions to watch-only addresses</source>
        <translation type="unfinished">‫عمليات غير مؤكدة لعناوين المراقبة‬</translation>
    </message>
    <message>
        <source>Mined balance in watch-only addresses that has not yet matured</source>
        <translation type="unfinished">‫الرصيد المعدّن في عناوين المراقبة الذي لم ينضج بعد‬</translation>
    </message>
    <message>
        <source>Current total balance in watch-only addresses</source>
        <translation type="unfinished">‫الرصيد الإجمالي الحالي في عناوين المراقبة‬</translation>
    </message>
    <message>
        <source>Privacy mode activated for the Overview tab. To unmask the values, uncheck Settings-&gt;Mask values.</source>
        <translation type="unfinished">تم تنشيط وضع الخصوصية لعلامة التبويب "نظرة عامة". للكشف عن القيم ، قم بإلغاء تحديد الإعدادات-&gt; إخفاء القيم.</translation>
    </message>
</context>
<context>
    <name>PSBTOperationsDialog</name>
    <message>
        <source>Sign Tx</source>
        <translation type="unfinished">‫توقيع العملية‬</translation>
    </message>
    <message>
        <source>Broadcast Tx</source>
        <translation type="unfinished">‫بث العملية‬</translation>
    </message>
    <message>
        <source>Copy to Clipboard</source>
        <translation type="unfinished">نسخ إلى الحافظة</translation>
    </message>
    <message>
        <source>Save…</source>
        <translation type="unfinished">‫حفظ…‬</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished">إغلاق</translation>
    </message>
    <message>
        <source>Failed to load transaction: %1</source>
        <translation type="unfinished">‫فشل تحميل العملية: %1‬</translation>
    </message>
    <message>
        <source>Failed to sign transaction: %1</source>
        <translation type="unfinished">فشل توقيع المعاملة: %1</translation>
    </message>
    <message>
        <source>Cannot sign inputs while wallet is locked.</source>
        <translation type="unfinished">‫لا يمكن توقيع المدخلات والمحفظة مقفلة.‬</translation>
    </message>
    <message>
        <source>Could not sign any more inputs.</source>
        <translation type="unfinished">تعذر توقيع المزيد من المدخلات.</translation>
    </message>
    <message>
        <source>Signed %1 inputs, but more signatures are still required.</source>
        <translation type="unfinished">‫تم توقيع %1 مدخلات، مطلوب توقيعات اضافية.‬</translation>
    </message>
    <message>
        <source>Signed transaction successfully. Transaction is ready to broadcast.</source>
        <translation type="unfinished">‫تم توقيع المعاملة بنجاح. العملية جاهزة للبث.‬</translation>
    </message>
    <message>
        <source>Unknown error processing transaction.</source>
        <translation type="unfinished">‫خطأ غير معروف في معالجة العملية.‬</translation>
    </message>
    <message>
        <source>Transaction broadcast successfully! Transaction ID: %1</source>
        <translation type="unfinished">‫تم بث العملية بنجاح! معرّف العملية: %1‬</translation>
    </message>
    <message>
        <source>Transaction broadcast failed: %1</source>
        <translation type="unfinished">‫فشل بث العملية: %1‬</translation>
    </message>
    <message>
        <source>PSBT copied to clipboard.</source>
        <translation type="unfinished">‫نسخ المعاملة الموقعة جزئيا إلى الحافظة.‬</translation>
    </message>
    <message>
        <source>Save Transaction Data</source>
        <translation type="unfinished">حفظ بيانات العملية</translation>
    </message>
    <message>
        <source>Partially Signed Transaction (Binary)</source>
        <extracomment>Expanded name of the binary PSBT file format. See: BIP 174.</extracomment>
        <translation type="unfinished">معاملة موقعة جزئيًا (ثنائي)</translation>
    </message>
    <message>
        <source>PSBT saved to disk.</source>
        <translation type="unfinished">‫تم حفظ المعاملة الموقعة جزئيا على وحدة التخزين.‬</translation>
    </message>
    <message>
        <source>own address</source>
        <translation type="unfinished">عنوانه</translation>
    </message>
    <message>
        <source>Unable to calculate transaction fee or total transaction amount.</source>
        <translation type="unfinished">‫غير قادر على حساب رسوم العملية أو إجمالي قيمة العملية.‬</translation>
    </message>
    <message>
        <source>Pays transaction fee: </source>
        <translation type="unfinished">‫دفع رسوم العملية: ‬</translation>
    </message>
    <message>
        <source>Total Amount</source>
        <translation type="unfinished">القيمة الإجمالية</translation>
    </message>
    <message>
        <source>or</source>
        <translation type="unfinished">أو</translation>
    </message>
    <message>
        <source>Transaction has %1 unsigned inputs.</source>
        <translation type="unfinished">‫المعاملة تحتوي على %1 من المدخلات غير موقعة.‬</translation>
    </message>
    <message>
        <source>Transaction is missing some information about inputs.</source>
        <translation type="unfinished">تفتقد المعاملة إلى بعض المعلومات حول المدخلات </translation>
    </message>
    <message>
        <source>Transaction still needs signature(s).</source>
        <translation type="unfinished">المعاملة ما زالت تحتاج التوقيع.</translation>
    </message>
    <message>
        <source>(But no wallet is loaded.)</source>
        <translation type="unfinished">‫(لكن لم يتم تحميل محفظة.)‬</translation>
    </message>
    <message>
        <source>(But this wallet cannot sign transactions.)</source>
        <translation type="unfinished">‫(لكن لا يمكن توقيع العمليات بهذه المحفظة.)‬</translation>
    </message>
    <message>
        <source>(But this wallet does not have the right keys.)</source>
        <translation type="unfinished">‫(لكن هذه المحفظة لا تحتوي على المفاتيح الصحيحة.)‬</translation>
    </message>
    <message>
        <source>Transaction is fully signed and ready for broadcast.</source>
        <translation type="unfinished">‫المعاملة موقعة بالكامل وجاهزة للبث.‬</translation>
    </message>
    <message>
        <source>Transaction status is unknown.</source>
        <translation type="unfinished">‫حالة العملية غير معروفة.‬</translation>
    </message>
</context>
<context>
    <name>PaymentServer</name>
    <message>
        <source>Payment request error</source>
        <translation type="unfinished">خطأ في طلب الدفع</translation>
    </message>
    <message>
        <source>Cannot start bitcoin: click-to-pay handler</source>
        <translation type="unfinished">لا يمكن تشغيل بتكوين: معالج النقر للدفع</translation>
    </message>
    <message>
        <source>URI handling</source>
        <translation type="unfinished">التعامل مع العنوان</translation>
    </message>
    <message>
        <source>'bitcoin://' is not a valid URI. Use 'bitcoin:' instead.</source>
        <translation type="unfinished">'bitcoin://' هو ليس عنوان URL صالح. استعمل 'bitcoin:' بدلا من ذلك.</translation>
    </message>
    <message>
        <source>Cannot process payment request because BIP70 is not supported.
Due to widespread security flaws in BIP70 it's strongly recommended that any merchant instructions to switch wallets be ignored.
If you are receiving this error you should request the merchant provide a BIP21 compatible URI.</source>
        <translation type="unfinished">‫لا يمكن معالجة طلب الدفع لأن BIP70 غير مدعوم.
‬‫‫‫نظرًا لوجود عيوب أمنية كبيرة في ‫BIP70 يوصى بشدة بتجاهل أي تعليمات من المستلمين لتبديل المحافظ.
‬‫‫‫إذا كنت تتلقى هذا الخطأ ، يجب أن تطلب من المستلم تقديم عنوان URI متوافق مع BIP21.‬</translation>
    </message>
    <message>
        <source>URI cannot be parsed! This can be caused by an invalid Bitcoin address or malformed URI parameters.</source>
        <translation type="unfinished">‫لا يمكن تحليل العنوان (URI)! يمكن أن يحدث هذا بسبب عنوان بتكوين غير صالح أو محددات عنوان غير صحيحة.‬</translation>
    </message>
    <message>
        <source>Payment request file handling</source>
        <translation type="unfinished">التعامل مع ملف طلب الدفع</translation>
    </message>
</context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>Ping</source>
        <extracomment>Title of Peers Table column which indicates the current latency of the connection with the peer.</extracomment>
        <translation type="unfinished">رنين</translation>
    </message>
    <message>
        <source>Peer</source>
        <extracomment>Title of Peers Table column which contains a unique number used to identify a connection.</extracomment>
        <translation type="unfinished">الأقران</translation>
    </message>
    <message>
        <source>Age</source>
        <extracomment>Title of Peers Table column which indicates the duration (length of time) since the peer connection started.</extracomment>
        <translation type="unfinished">العمر</translation>
    </message>
    <message>
        <source>Direction</source>
        <extracomment>Title of Peers Table column which indicates the direction the peer connection was initiated from.</extracomment>
        <translation type="unfinished">جهة</translation>
    </message>
    <message>
        <source>Sent</source>
        <extracomment>Title of Peers Table column which indicates the total amount of network information we have sent to the peer.</extracomment>
        <translation type="unfinished">تم الإرسال</translation>
    </message>
    <message>
        <source>Type</source>
        <extracomment>Title of Peers Table column which describes the type of peer connection. The "type" describes why the connection exists.</extracomment>
        <translation type="unfinished">النوع</translation>
    </message>
    <message>
        <source>Network</source>
        <extracomment>Title of Peers Table column which states the network the peer connected through.</extracomment>
        <translation type="unfinished">الشبكة</translation>
    </message>
    <message>
        <source>Inbound</source>
        <extracomment>An Inbound Connection from a Peer.</extracomment>
        <translation type="unfinished">‫وارد‬</translation>
    </message>
    <message>
        <source>Outbound</source>
        <extracomment>An Outbound Connection to a Peer.</extracomment>
        <translation type="unfinished">‫صادر‬</translation>
    </message>
</context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>Local Addresses</source>
        <translation type="unfinished">العناوين المحلية</translation>
    </message>
    <message>
        <source>Network addresses that your Bitcoin node is currently using to communicate with other nodes.</source>
        <translation type="unfinished">عناوين الشبكة التي تستخدمها عقدةالبتكوين الخاصة بك حاليًا للتواصل مع العقد الأخرى.</translation>
    </message>
    <message>
        <source>Sent</source>
        <translation type="unfinished">تم الإرسال</translation>
    </message>
    <message>
        <source>Hide Peers Detail</source>
        <translation type="unfinished">إخفاء تفاصيل الأقران</translation>
    </message>
    <message>
        <source>Node window</source>
        <translation type="unfinished">‫نافذة النود‬</translation>
    </message>
    <message>
        <source>None</source>
        <translation type="unfinished">لا شيء</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">‫نسخ &amp;القيمة‬</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Wallet:</source>
        <translation type="unfinished">المحفظة:</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(بدون وسم)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Change:</source>
        <translation type="unfinished">تعديل:</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation type="unfinished">نسخ الكمية </translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation type="unfinished">‫نسخ القيمة‬</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation type="unfinished">نسخ بعد الرسوم</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation type="unfinished">‫نسخ الفكة‬</translation>
    </message>
    <message>
        <source>Creates a Partially Signed Bitcoin Transaction (PSBT) for use with e.g. an offline %1 wallet, or a PSBT-compatible hardware wallet.</source>
        <translation type="unfinished">‫أنشئ معاملة بتكوين موقعة جزئيا (PSBT) للاستعمال مع محفظة %1 غير متصلة بالشبكة مثلا، أو محفظة خارجية متوافقة مع الـ(PSBT).‬</translation>
    </message>
    <message>
        <source>Save Transaction Data</source>
        <translation type="unfinished">حفظ بيانات العملية</translation>
    </message>
    <message>
        <source>Partially Signed Transaction (Binary)</source>
        <extracomment>Expanded name of the binary PSBT file format. See: BIP 174.</extracomment>
        <translation type="unfinished">معاملة موقعة جزئيًا (ثنائي)</translation>
    </message>
    <message>
        <source>or</source>
        <translation type="unfinished">أو</translation>
    </message>
    <message>
        <source>Total Amount</source>
        <translation type="unfinished">القيمة الإجمالية</translation>
    </message>
    <message numerus="yes">
        <source>Estimated to begin confirmation within %n block(s).</source>
        <translation type="unfinished">
            <numerusform>Estimated to begin confirmation within %n block(s).</numerusform>
            <numerusform>Estimated to begin confirmation within %n block(s).</numerusform>
            <numerusform>Estimated to begin confirmation within %n block(s).</numerusform>
            <numerusform>Estimated to begin confirmation within %n block(s).</numerusform>
            <numerusform>Estimated to begin confirmation within %n block(s).</numerusform>
            <numerusform>Estimated to begin confirmation within %n block(s).</numerusform>
        </translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(بدون وسم)</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>own address</source>
        <translation type="unfinished">عنوانه</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform>matures in %n more block(s)</numerusform>
            <numerusform>matures in %n more block(s)</numerusform>
            <numerusform>matures in %n more block(s)</numerusform>
            <numerusform>matures in %n more block(s)</numerusform>
            <numerusform>matures in %n more block(s)</numerusform>
            <numerusform>matures in %n more block(s)</numerusform>
        </translation>
    </message>
    <message>
        <source>Generated coins must mature %1 blocks before they can be spent. When you generated this block, it was broadcast to the network to be added to the block chain. If it fails to get into the chain, its state will change to "not accepted" and it won't be spendable. This may occasionally happen if another node generates a block within a few seconds of yours.</source>
        <translation type="unfinished">النقود المولدة يجب أن تنضج %1 من الكتل قبل أن يكون بالإمكان إنفاقهم. عندما تولد أنت هذه الكتلة، تكون قد بثت الى الشبكة ليتم اضافتها لسلسلة الكتل. اذا فشلت في الدخول الى السلسلة، حالتها سوف تتغير الى "غير مقبولة" ولن تكون قابلة للإنفاق. هذا قد يحدث أحيانا اذا قامت عقدة أخرى بتوليد كتلة خلال ثوان معدودة من قيامك بنفس العملية.</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">‫القيمة‬</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Type</source>
        <translation type="unfinished">النوع</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(بدون وسم)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">‫نسخ &amp;القيمة‬</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished">النوع</translation>
    </message>
    </context>
<context>
    <name>WalletFrame</name>
    <message>
        <source>Create a new wallet</source>
        <translation type="unfinished">إنشاء محفظة جديدة</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">خطأ</translation>
    </message>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">و إستخرج</translation>
    </message>
    <message>
        <source>Wallet Data</source>
        <extracomment>Name of the wallet data file format.</extracomment>
        <translation type="unfinished">بيانات المحفظة</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">إلغاء</translation>
    </message>
</context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Error starting/committing db txn for wallet transactions removal process</source>
        <translation type="unfinished">خطأ بدء/ارتكاب DB TXN لعملية إزالة معاملات المحفظة</translation>
    </message>
    <message>
        <source>Invalid value detected for '-wallet' or '-nowallet'. '-wallet' requires a string value, while '-nowallet' accepts only '1' to disable all wallets</source>
        <translation type="unfinished">قيمة غير صالحة تم اكتشافها لـ "-wallet" أو "-Nowallet". يتطلب "-wallet" قيمة سلسلة ، في حين أن "-Nowallet" تقبل فقط "1" لتعطيل جميع المحافظ</translation>
    </message>
    <message>
        <source>More than one onion bind address is provided. Using %s for the automatically created Tor onion service.</source>
        <translation type="unfinished">أكثر من عنوان مربوط بالonion مقدم. استخدام %s من أجل خدمة تور (Tor) المنشأة تلقائيا.</translation>
    </message>
    <message>
        <source>Maximum transaction weight is too low, can not accommodate change output</source>
        <translation type="unfinished">الحد الأقصى لوزن المعاملة منخفض جدًا، ولا يمكنه استيعاب مخرجات التغيير</translation>
    </message>
    <message>
        <source>Error loading databases</source>
        <translation type="unfinished">خطأ تحميل قواعد البيانات</translation>
    </message>
    <message>
        <source>Error opening coins database</source>
        <translation type="unfinished">خطأ فتح قاعدة بيانات العملات المعدنية</translation>
    </message>
    <message>
        <source>The transactions removal process can only be executed within a db txn</source>
        <translation type="unfinished">لا يمكن تنفيذ عملية إزالة المعاملات إلا داخل DB TXN</translation>
    </message>
    <message>
        <source>Do you want to rebuild the databases now?</source>
        <translation type="unfinished">هل تريد إعادة بناء قواعد البيانات الآن؟</translation>
    </message>
    <message>
        <source>Error: Wallet does not exist</source>
        <translation type="unfinished">خطأ: محفظة غير موجودة</translation>
    </message>
    <message>
        <source>Error: cannot remove legacy wallet records</source>
        <translation type="unfinished">خطأ: لا يمكن إزالة سجلات المحفظة القديمة</translation>
    </message>
    </context>
</TS>